@@ -1,10 +1,27 @@
 from pydantic import BaseModel, ValidationError
-from typing import Union
+from typing import Union, Optional, List
 
 from moloni.base.client import MoloniBaseClient
 from moloni.base.helpers import endpoint, fill_query_params, validate_data
 
 
+class Suppliers(BaseModel):
+    cost_price: str
+    supplier_id: str
+
+
+class Taxes(BaseModel):
+    cumulative: str
+    order: str
+    tax_id: str
+    value: str
+
+
+class Warehouses(BaseModel):
+    stock: str
+    warehouse_id: str
+
+
 class UsersGetAllModel(BaseModel):
     company_id: Union[str, int]
 
